==> neural-speed-0.3.tar.gz: neural-speed-0.3/neural_speed/models/phi/phi.h <==
//  Copyright (c) 2023 Intel Corporation
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

#ifndef PHI_H
#define PHI_H

#include "models/model_utils/model_files.h"
#include "models/model_utils/model_types.h"

enum new_model {
  MDOEL_UNKNOWN,
  PHI,
};

static const model_scratch phi_mem_req(int n_layers) {
  switch (n_layers) {
    case 24:
      return {512ull * MB, 512ull * MB, 1026ull * MB};
    case 32:
      return {1024ull * MB, 1024ull * MB, 1026ull * MB};
    default:
      MODEL_ASSERT(false);
  }
}

class phi : public IModel {
 private:
  model_archs name = MODEL_PHI;
  std::unique_ptr<model_model_loader> ml;
  uint32_t n_layer, n_embd, n_ff, n_vocab;
  int n_ctx, n_gpu_layer;
  bool use_mmap, use_mlock, vocab_only;
  model_scratch scratch;

 public:
  void init(const char* path_model, model_context* ctx, int n_gpu_layers, bool use_mmap_, bool use_mlock_,
            bool vocab_only_) override;
  void load(model_context* ctx, model_progress_callback progress_callback, void* progress_callback_user_data) override;
};

#endif  // PHI_H

==> neural-speed-1.0.tar.gz: neural-speed-1.0/neural_speed/models/phi/phi.h <==
//  Copyright (c) 2023 Intel Corporation
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

#ifndef PHI_H
#define PHI_H

#include "models/model_utils/model_files.h"
#include "models/model_utils/model_types.h"

enum new_model {
  MDOEL_UNKNOWN,
  PHI,
};

static const model_scratch phi_mem_req(int n_layers, float scratch_size_ratio = 1.0f) {
  switch (n_layers) {
    case 24:
      return {
          static_cast<unsigned long long>(scratch_size_ratio * 512) * MB,
          static_cast<unsigned long long>(scratch_size_ratio * 512) * MB,
          static_cast<unsigned long long>(scratch_size_ratio * 1024) * MB,
      };
    case 32:
      return {
          static_cast<unsigned long long>(scratch_size_ratio * 1024) * MB,
          static_cast<unsigned long long>(scratch_size_ratio * 1024) * MB,
          static_cast<unsigned long long>(scratch_size_ratio * 1024) * MB,
      };
    default:
      MODEL_ASSERT(false);
  }
}

class phi : public IModel {
 private:
  model_archs name = MODEL_PHI;
  std::unique_ptr<model_model_loader> ml;
  uint32_t n_layer, n_embd, n_ff, n_vocab;
  int n_ctx, n_gpu_layer;
  bool use_mmap, use_mlock, vocab_only;
  model_scratch scratch;

 public:
  void init(const char* path_model, model_context* ctx, int n_gpu_layers, bool use_mmap_, bool use_mlock_,
            bool vocab_only_) override;
  void load(model_context* ctx, model_progress_callback progress_callback, void* progress_callback_user_data) override;
};

#endif  // PHI_H
